/**
 * @author @thkruz Theodore Kruczek
 * @license AGPL-3.0-or-later
 * @copyright (c) 2020-2024 Theodore Kruczek
 *
 * Orbital Object ToolKit is free software: you can redistribute it and/or modify it under the
 * terms of the GNU Affero General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * Orbital Object ToolKit is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with
 * Orbital Object ToolKit. If not, see <http://www.gnu.org/licenses/>.
 */
import { Propagator } from './Propagator';
// / SGP4 propagator.
export class Sgp4Propagator extends Propagator {
    tle;
    // / Create a new [Sgp4Propagator] object from a [TLE].
    constructor(tle) {
        super();
        this.tle = tle;
        this._cacheState = tle.state.toJ2000();
    }
    _cacheState;
    _checkpoints = [];
    get state() {
        return this._cacheState;
    }
    ephemerisManeuver(start, finish, maneuvers, interval = 60.0) {
        throw new Error('Maneuvers cannot be modelled with SGP4.');
    }
    maneuver(maneuver, interval = 60.0) {
        throw new Error('Maneuvers cannot be modelled with SGP4.');
    }
    propagate(epoch) {
        this._cacheState = this.tle.propagate(epoch).toJ2000();
        return this._cacheState;
    }
    reset() {
        this._cacheState = this.tle.state.toJ2000();
    }
    checkpoint() {
        this._checkpoints.push(this._cacheState);
        return this._checkpoints.length - 1;
    }
    clearCheckpoints() {
        this._checkpoints = [];
    }
    restore(index) {
        this._cacheState = this._checkpoints[index];
    }
}
//# sourceMappingURL=Sgp4Propagator.js.map